@@ -10,12 +10,13 @@ from __future__ import annotations  # Make typing work for the enclosing class
 
 __author__ = "Jonas Van Der Donckt, Emiel Deprost, Jeroen Van Der Donckt"
 
+import os
 import dill
 import pandas as pd
 import numpy as np
 
 from pathlib import Path
-from typing import Dict, List, Optional, Tuple, Union
+from typing import Dict, List, Optional, Tuple, Union, Any
 from pathos.multiprocessing import ProcessPool
 from tqdm.auto import tqdm
 
@@ -52,7 +53,7 @@ class FeatureCollection:
         #   tuple(tuple(str), float OR pd.timedelta, float OR pd.timedelta)
         # The outer tuple's values correspond to (series_key(s), window, stride)
         self._feature_desc_dict: Dict[
-            Tuple[Tuple[str], pd.Timedelta, pd.Timedelta], List[FeatureDescriptor]
+            Tuple[Tuple[str, ...], pd.Timedelta, pd.Timedelta], List[FeatureDescriptor]
         ] = {}
 
         if feature_descriptors:
@@ -137,10 +138,10 @@ class FeatureCollection:
                 raise TypeError(f"type: {type(feature)} is not supported - {feature}")
 
     @staticmethod
-    def _executor(idx: int):
+    def _executor(idx: int, error_val: Optional[Any] = None):
         # global get_stroll_func
         stroll, function = get_stroll_func(idx)
-        return stroll.apply_func(function)
+        return stroll.apply_func(function, error_val)
 
     def _stroll_feat_generator(
         self, series_dict: Dict[str, pd.Series], window_idx: str, approve_sparsity: bool
@@ -181,6 +182,7 @@ class FeatureCollection:
         return_df: Optional[bool] = False,
         window_idx: Optional[str] = "end",
         approve_sparsity: Optional[bool] = False,
+        error_val: Optional[Any] = None,
         show_progress: Optional[bool] = False,
         logging_file_path: Optional[Union[str, Path]] = None,
         n_jobs: Optional[int] = None,
@@ -217,6 +219,13 @@ class FeatureCollection:
             Bool indicating whether the user acknowledges that there may be sparsity
             (i.e., irregularly sampled data), by default False.
             If False and sparsity is observed, a warning is raised.
+        error_val : Any, optional  # TODO: other name??
+            The value that gets returned when there is an error in the function call, by
+            default None. If `error_val` is None, than no other values are returned in 
+            case of an error, and thus the error is thrown. If `error_val` is not None, 
+            than the value is returned ``len(self.output_names)`` times.
+            Note that an error is most likely due to an empty / sparse window. This is 
+            thus a convenient way to return default values in such cases.
         show_progress: bool, optional
             If True, the progress will be shown with a progressbar, by default False.
         logging_file_path : Union[str, Path], optional
@@ -273,18 +282,24 @@ class FeatureCollection:
         get_stroll_func = self._stroll_feat_generator(
             series_dict, window_idx, approve_sparsity
         )
+        nb_stroll_funcs = self._get_stroll_feat_length()
+
+        if n_jobs is None: 
+            n_jobs = os.cpu_count()
+        n_jobs = min(n_jobs, nb_stroll_funcs)
 
         if n_jobs in [0, 1]:
-            idxs = range(self._get_stroll_feat_length())
+            idxs = range(nb_stroll_funcs)
             if show_progress:
                 idxs = tqdm(idxs)
-            calculated_feature_list = [self._executor(idx) for idx in idxs]
+            calculated_feature_list = [self._executor(idx, error_val) for idx in idxs]
         else:
             # https://pathos.readthedocs.io/en/latest/pathos.html#usage
             with ProcessPool(nodes=n_jobs, source=True) as pool:
                 results = pool.uimap(
                     self._executor,
-                    range(self._get_stroll_feat_length()),
+                    range(nb_stroll_funcs),
+                    [error_val]*nb_stroll_funcs,
                 )
                 if show_progress:
                     results = tqdm(results, total=self._get_stroll_feat_length())
